==> apache-storm-2.4.0-src.zip: apache-storm-2.4.0/storm-server/src/test/java/org/apache/storm/container/docker/DockerPsCommandTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.storm.container.docker;

import static org.junit.Assert.assertEquals;


import org.junit.Before;
import org.junit.Test;

public class DockerPsCommandTest {

    private DockerPsCommand dockerPsCommand;

    @Before
    public void setup() {
        dockerPsCommand = new DockerPsCommand();
    }

    @Test
    public void getCommandOption() {
        assertEquals("ps", dockerPsCommand.getCommandOption());
    }

    @Test
    public void getCommandWithArguments() {
        dockerPsCommand.withNameFilter("container_name");
        dockerPsCommand.withQuietOption();
        assertEquals("ps --filter=name=container_name --quiet=true",
            dockerPsCommand.getCommandWithArguments());
    }
}

==> apache-storm-2.8.3-src.zip: apache-storm-2.8.3/storm-server/src/test/java/org/apache/storm/container/docker/DockerPsCommandTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.storm.container.docker;

import static org.junit.jupiter.api.Assertions.assertEquals;


import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

public class DockerPsCommandTest {

    private DockerPsCommand dockerPsCommand;

    @BeforeEach
    public void setup() {
        dockerPsCommand = new DockerPsCommand();
    }

    @Test
    public void getCommandOption() {
        assertEquals("ps", dockerPsCommand.getCommandOption());
    }

    @Test
    public void getCommandWithArguments() {
        dockerPsCommand.withNameFilter("container_name");
        dockerPsCommand.withQuietOption();
        assertEquals("ps --filter=name=container_name --quiet=true",
            dockerPsCommand.getCommandWithArguments());
    }
}
